@@ -7,7 +7,7 @@ from typing import Dict, List, Optional, Union
 from uuid import UUID
 
 from dateutil import parser
-from pydantic import BaseModel, ValidationError, validator
+from pydantic import BaseModel, ValidationError, constr, validator
 
 from ..utils.logger import payment_logger as logger
 
@@ -19,7 +19,7 @@ def check_iso_format(v: str):
         raise ValidationError('date must be ISO8601 format')
 
 
-def check_isoformat_none_case(v: Union[str, None]):
+def check_isoformat_none_case(v: Optional[str]):
     if v is not None:
         try:
             return parser.parse(v)
@@ -86,14 +86,14 @@ class PaymentDataSplit(BaseModel):
 
 
 class PaymentData(BaseModel):
-    transaction_id: Union[str, None]
-    paid_at: Union[str, None]
+    transaction_id: Optional[str]
+    paid_at: Optional[str]
     expire_at: str
     amount: float
     currency: CurrencyType
-    notice_code: Union[str, None]
+    notice_code: Optional[str]
     iud: str
-    iuv: Union[str, None]
+    iuv: Optional[str]
     split: Union[
         List[Dict[str, Union[float, str, None]]],
         List[Optional[PaymentDataSplit]],
@@ -122,9 +122,9 @@ class PaymentData(BaseModel):
 
 
 class OnlinePaymentBegin(BaseModel):
-    url: Union[str, None]
-    last_opened_at: Union[str, None]
-    method: Union[HttpMethodType, None]
+    url: Optional[str]
+    last_opened_at: Optional[str]
+    method: Optional[HttpMethodType]
 
     last_opened_at_must_be_iso8601 = validator('last_opened_at', allow_reuse=True)(check_isoformat_none_case)
 
@@ -149,9 +149,9 @@ class Receipt(OnlinePaymentBegin):
 
 
 class Notify(BaseModel):
-    url: str
-    method: HttpMethodType
-    sent_at: Union[str, None]
+    url: Optional[str]
+    method: Optional[HttpMethodType]
+    sent_at: Optional[str]
 
     sent_at_must_be_iso8601 = validator('sent_at', allow_reuse=True)(check_isoformat_none_case)
 
@@ -164,10 +164,10 @@ class Notify(BaseModel):
 
 
 class Update(BaseModel):
-    url: Union[str, None]
-    last_check_at: Union[str, None]
-    next_check_at: Union[str, None]
-    method: Union[HttpMethodType, None]
+    url: Optional[str]
+    last_check_at: Optional[str]
+    next_check_at: Optional[str]
+    method: Optional[HttpMethodType]
 
     last_check_at_must_be_iso8601 = validator('last_check_at', allow_reuse=True)(check_isoformat_none_case)
     next_check_at_must_be_iso8601 = validator('next_check_at', allow_reuse=True)(check_isoformat_none_case)
@@ -185,7 +185,7 @@ class Links(BaseModel):
     online_payment_landing: OnlinePaymentLanding
     offline_payment: OfflinePayment
     receipt: Receipt
-    notify: List[Notify]
+    notify: Optional[List[Notify]]
     update: Update
 
     class Config:
@@ -204,14 +204,14 @@ class Payer(BaseModel):
     type: PayerType
     tax_identification_number: str
     name: str
-    family_name: Union[str, None]
-    street_name: Union[str, None]
-    building_number: Union[str, None]
-    postal_code: Union[str, None]
-    town_name: Union[str, None]
-    country_subdivision: Union[str, None]
-    country: Union[str, None]
-    email: Union[str, None]
+    family_name: Optional[str]
+    street_name: Optional[str]
+    building_number: Optional[str]
+    postal_code: Optional[str]
+    town_name: Optional[str]
+    country_subdivision: Optional[str]
+    country: Optional[str]
+    email: Optional[str]
 
     class Config:
         validate_all = True
@@ -236,7 +236,7 @@ class Payment(BaseModel):
     created_at: str
     updated_at: str
     status: PaymentStatus
-    reason: str
+    reason: constr(max_length=140)
     remote_id: UUID
     payment: PaymentData
     links: Links
@@ -250,12 +250,6 @@ class Payment(BaseModel):
         validate_all = True
         validate_assignment = True
 
-    @validator('reason')
-    def reason_must_be_lteq_140_chars(cls, v):
-        if len(v) > 140:
-            raise ValidationError('reason must be less than or equal to 140 characters')
-        return v
-
     created_at_must_be_iso8601 = validator('created_at', allow_reuse=True)(check_iso_format)
     updated_at_must_be_iso8601 = validator('updated_at', allow_reuse=True)(check_iso_format)
 
