@@ -305,6 +305,15 @@ def get_notify_data(**kwargs):
     }
 
 
+def get_empty_notify_data(**kwargs):
+    return {
+        'url': None,
+        'method': None,
+        'sent_at': None,
+        **kwargs,
+    }
+
+
 def get_offline_payment_data(**kwargs):
     return {'url': None, 'last_opened_at': None, 'method': 'GET', **kwargs}
 
