@@ -23,6 +23,7 @@ from oc_python_sdk.models.payment import (
 )
 
 from ._helpers import (
+    get_empty_notify_data,
     get_links_data,
     get_notify_data,
     get_online_payment_begin_data,
@@ -129,6 +130,9 @@ class PaymentTestCase(TestCase):
         payment = Payment(**get_payment_event_data())
         validated_split = payment.payment.split
 
+        payment_empty_notify = Payment(**get_payment_event_data())
+        payment_empty_notify.links.notify = None
+
         payment_data_v2 = payment.payment
         payment_data_v2.set_split(get_split_data_v2())
         payment_v2 = Payment(**get_payment_event_data(payment=payment_data_v2))
@@ -145,6 +149,7 @@ class PaymentTestCase(TestCase):
         split = PaymentDataSplit(**get_split_data())
         online_payment_begin = OnlinePaymentBegin(**get_online_payment_begin_data())
         notify = Notify(**get_notify_data())
+        notify_no_data = Notify(**get_empty_notify_data())
         update = Update(**get_update_data())
         links = Links(**get_links_data())
         payer = Payer(**get_payer_data())
@@ -182,6 +187,7 @@ class PaymentTestCase(TestCase):
         self.assertEqual(json.loads(payment.payer.type.json()), PayerType.TYPE_HUMAN.value)
         self.assertEqual(json.loads(payment.payment.currency.json()), CurrencyType.CURRENCY_EUR.value)
         self.assertEqual(json.loads(payment.links.notify[0].method.json()), HttpMethodType.HTTP_METHOD_POST.value)
+        self.assertEqual(json.loads(payment_empty_notify.json())['links']['notify'], None)
         self.assertEqual(json.loads(split.json())['code'], 'CODE')
         self.assertEqual(json.loads(payment_data.json())['amount'], 1)
         self.assertEqual(json.loads(online_payment_begin.json())['url'], None)
@@ -191,6 +197,7 @@ class PaymentTestCase(TestCase):
             'comune-di-bugliano/api/applications/'
             'a51cc065-4fb1-4ace-8d3f-e3a70c867472/payment',
         )
+        self.assertEqual(json.loads(notify_no_data.json()), {'url': None, 'method': None, 'sent_at': None})
         self.assertEqual(json.loads(update.json())['url'], None)
         self.assertEqual(len(json.loads(links.json())['notify']), 1)
         self.assertEqual(json.loads(payer.json())['type'], PayerType.TYPE_HUMAN.value)
